# pykickloc
A python implementation of the KickLoc cooperative localization algorithm.

## Install

```bash
pip3 install pykickloc
```

## References

* Xiong, H., & Sichitiu, M. L. (2019). [A Lightweight Localization Solution for Small, Low Resources WSNs.](https://www.mdpi.com/2224-2708/8/2/26/pdf) Journal of Sensor and Actuator Networks, 8(2), 26.

*  Xiong, H.; Sichitiu, M.L. [KickLoc: Simple, Distributed Localization for Wireless Sensor Networks.](http://ieeexplore.ieee.org/iel7/7814392/7814995/07815031.pdf) In Proceedings of the 2016 IEEE 13th International Conference on Mobile Ad Hoc and Sensor Systems (MASS), 10–13 October 2016; pp. 228–236.
